@@ -2,7 +2,7 @@ package Bundle::dualLived;
 
 use strict;
 
-$Bundle::dualLived::VERSION = '1.03';
+$Bundle::dualLived::VERSION = '1.04';
 
 1;
 
@@ -44,8 +44,6 @@ version
 
 Test::Harness
 
-Archive::Extract
-
 Archive::Tar
 
 Attribute::Handlers
@@ -54,8 +52,6 @@ AutoLoader
 
 B::Debug
 
-B::Lint
-
 Carp
 
 CGI
@@ -68,24 +64,20 @@ CPAN::Meta::Requirements
 
 CPAN::Meta::YAML
 
-CPANPLUS
-
-CPANPLUS::Dist::Build
-
 Compress::Raw::Bzip2
 
 Compress::Raw::Zlib
 
 Compress::Zlib
 
+Config::Perl::V
+
 Cwd
 
 DB_File
 
 Data::Dumper
 
-Devel::InnerPackage
-
 Devel::PPPort
 
 Digest
@@ -94,6 +86,10 @@ Digest::MD5
 
 Digest::SHA
 
+Encode
+
+Env
+
 Exporter
 
 ExtUtils::CBuilder
@@ -138,18 +134,18 @@ IPC::Cmd
 
 IPC::Msg
 
+IPC::SysV
+
 JSON::PP
 
 List::Util
 
-Locale::Codes::Constants
+Locale::Codes
 
 Locale::Maketext
 
 Locale::Maketext::Simple
 
-Log::Message
-
 MIME::Base64
 
 Math::BigInt
@@ -174,10 +170,12 @@ Module::Loaded
 
 Module::Metadata
 
-Module::Pluggable
-
 Net::Cmd
 
+Net::Ping
+
+NEXT
+
 Package::Constants
 
 Params::Check
@@ -192,8 +190,6 @@ Pod::Checker
 
 Pod::Escapes
 
-Pod::LaTeX
-
 Pod::Man
 
 Pod::Perldoc
@@ -206,7 +202,7 @@ Safe
 
 SelfLoader
 
-Shell
+Search::Dict
 
 Socket
 
@@ -218,18 +214,18 @@ Term::ANSIColor
 
 Term::Cap
 
-Term::UI
+Term::ReadLine
 
 Test
 
 Test::Simple
 
+Text::Abbrev
+
 Text::Balanced
 
 Text::ParseWords
 
-Text::Soundex
-
 Text::Tabs
 
 Thread::Queue
@@ -258,7 +254,7 @@ XSLoader
 
 =head1 AUTHOR
 
-Version 1.03 Kevin W. Henwood, <Khen1950fx@aol.com>
+Version 1.04 Kevin W. Henwood, <Khen1950fx@yahoo.com>
 
 head1 COPYRIGHT AND LICENSE
 
